@@ -450,9 +450,14 @@ class AccessibleModel(gtk.TreeStore, ToolsAccessor):
     '''
     if accessible is not None:
       icon = getIcon(accessible)
-      name = accessible.name
-      role = accessible.getLocalizedRoleName()
-      count = str(accessible.childCount)
+      if self.isMyApp(accessible):
+        name = "Accerciser"
+        role = "accerciser"
+        count = "0"
+      else:
+        name = accessible.name
+        role = accessible.getLocalizedRoleName()
+        count = str(accessible.childCount)
     else:
       icon = None
       if not dummy:
@@ -938,22 +943,6 @@ class AccessibleTreeView(gtk.TreeView, ToolsAccessor):
     '''
     A cellrenderer data function. renderer's this application's node as insensitive.
 
-    @param tvc: A treeview column.
-    @type tvc: L{gtk.TreeViewColumn}
-    @param cellrenderer: The cellrenderer that needs to be tweaked.
-    @type cellrenderer: L{gtk.CellRenderer}
-    @param model: The treeview's data model.
-    @type model: L{AccessibleModel}
-    @param iter: The iter at the given row.
-    @type iter: L{gtk.TreeIter}
-    '''
-    # TODO: Remove idle_add when at-spi2 reentrancy issues are fixed
-    GLib.idle_add(self._accCellDataFuncReal, tvc, cellrenderer, model, iter_id)
-
-  def _accCellDataFuncReal(self, tvc, cellrenderer, model, iter_id):
-    '''
-    Called by _acCellDataFunc when idle
-
     @param tvc: A treeview column.
     @type tvc: L{gtk.TreeViewColumn}
     @param cellrenderer: The cellrenderer that needs to be tweaked.
